@@ -18,7 +18,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from __future__ import absolute_import
 from django.conf import settings
 from horizon import exceptions
 import logging
@@ -29,7 +28,7 @@ from manilaclient import client as manila_client
 LOG = logging.getLogger(__name__)
 
 MANILA_UI_USER_AGENT_REPR = "manila_ui_plugin_for_horizon"
-MANILA_VERSION = "2.38"
+MANILA_VERSION = "2.44"
 MANILA_SERVICE_TYPE = "sharev2"
 
 # API static values
@@ -42,8 +41,11 @@ MANILA_QUOTA_FIELDS = {
     "share_snapshots",
     "share_snapshot_gigabytes",
     "share_networks",
+    "share_groups",
+    "share_group_snapshots",
 }
 
+
 # UI field names do not match data field names returned, have
 # a map to convert them.
 MANILA_QUOTA_FIELDS_DATA_MAP = {
@@ -51,7 +53,9 @@ MANILA_QUOTA_FIELDS_DATA_MAP = {
     "share_gigabytes": "gigabytes",
     "share_snapshots": "snapshots",
     "share_snapshot_gigabytes": "snapshot_gigabytes",
-    "share_networks": "share_networks"
+    "share_networks": "share_networks",
+    "share_groups": "share_groups",
+    "share_group_snapshots": "share_group_snapshots",
 }
 
 
@@ -111,12 +115,12 @@ def share_delete(request, share_id, share_group_id=None):
     )
 
 
-def share_update(request, share_id, name, description, is_public=''):
-    share_data = {'display_name': name, 'display_description': description}
-    if not isinstance(is_public, str):
-        is_public = str(is_public)
-    if is_public and is_public.lower() != 'none':
-        share_data['is_public'] = is_public
+def share_update(request, share_id, name, description, is_public=False):
+    share_data = {
+        'display_name': name,
+        'display_description': description,
+        'is_public': is_public
+    }
     return manilaclient(request).shares.update(share_id, **share_data)
 
 
@@ -190,8 +194,11 @@ def share_unmanage(request, share):
     return manilaclient(request).shares.unmanage(share)
 
 
-def share_extend(request, share_id, new_size):
-    return manilaclient(request).shares.extend(share_id, new_size)
+def share_resize(request, share_id, new_size, orig_size):
+    if orig_size > new_size:
+        return manilaclient(request).shares.shrink(share_id, new_size)
+    else:
+        return manilaclient(request).shares.extend(share_id, new_size)
 
 
 def share_revert(request, share, snapshot):
@@ -308,22 +315,25 @@ def security_service_get(request, sec_service_id, search_opts=None):
     return manilaclient(request).security_services.get(sec_service_id)
 
 
-def security_service_create(request, type, dns_ip=None, server=None,
+def security_service_create(request, type, dns_ip=None, ou=None, server=None,
                             domain=None, user=None, password=None, name=None,
                             description=None):
     return manilaclient(request).security_services.create(
-        type, dns_ip=dns_ip, server=server, domain=domain, user=user,
+        type, dns_ip=dns_ip, ou=ou, server=server, domain=domain, user=user,
         password=password, name=name, description=description)
 
 
-def security_service_update(request, security_service_id, dns_ip=None,
-                            server=None,
-                            domain=None, user=None, password=None, name=None,
-                            description=None):
+def security_service_update(request, security_service_id,
+                            dns_ip=None, ou=None,
+                            server=None, domain=None,
+                            password=None, user=None,
+                            name=None, description=None):
     return manilaclient(request).security_services.update(
-        security_service_id, dns_ip=dns_ip, server=server, domain=domain,
-        user=user, password=password, name=name, description=description,
-    )
+        security_service_id,
+        dns_ip=dns_ip, ou=ou,
+        server=server, domain=domain,
+        password=password, user=user,
+        name=name, description=description)
 
 
 def security_service_delete(request, security_service_id):
@@ -394,9 +404,10 @@ def share_type_get(request, share_type_id):
 
 
 def share_type_create(request, name, spec_driver_handles_share_servers,
-                      is_public=True):
+                      description=None, is_public=True):
     return manilaclient(request).share_types.create(
         name=name,
+        description=description,
         spec_driver_handles_share_servers=spec_driver_handles_share_servers,
         is_public=is_public)
 
@@ -640,3 +651,18 @@ def share_group_type_unset_specs(request, share_group_type, keys):
 def share_group_type_get_specs(request, share_group_type):
     return manilaclient(request).share_group_types.get(
         share_group_type).get_keys()
+
+
+# ####### User Messages # ########
+def messages_get(request, message_id):
+    return manilaclient(request).messages.get(message_id)
+
+
+def messages_list(request, search_opts=None, sort_key=None, sort_dir=None):
+    return manilaclient(request).messages.list(search_opts=search_opts,
+                                               sort_key=sort_key,
+                                               sort_dir=sort_dir)
+
+
+def messages_delete(request, message_id):
+    return manilaclient(request).messages.delete(message_id)
