@@ -26,6 +26,7 @@ from manila_ui.api import manila
 from manila_ui.dashboards import utils
 from manila_ui import features
 from manilaclient.common.apiclient import exceptions as m_exceptions
+import time
 
 
 class CreateForm(forms.SelfHandlingForm):
@@ -57,10 +58,7 @@ class CreateForm(forms.SelfHandlingForm):
         share_networks = manila.share_network_list(request)
         share_types = manila.share_type_list(request)
         self.fields['share_type'].choices = (
-            [("", "")] +
-            [(utils.transform_dashed_name(st.name), st.name)
-             for st in share_types]
-        )
+            [("", "")] + [(st.name, st.name) for st in share_types])
 
         availability_zones = manila.availability_zone_list(request)
         self.fields['availability_zone'].choices = (
@@ -84,18 +82,14 @@ class CreateForm(forms.SelfHandlingForm):
                 sn_choices = (
                     [('', '')] +
                     [(sn.id, sn.name or sn.id) for sn in share_networks])
-                sn_field_name = (
-                    self.sn_field_name_prefix +
-                    utils.transform_dashed_name(st.name)
-                )
+                sn_field_name = self.sn_field_name_prefix + st.name
                 sn_field = forms.ChoiceField(
                     label=_("Share Network"), required=True,
                     choices=sn_choices,
                     widget=forms.Select(attrs={
                         'class': 'switched',
                         'data-switch-on': 'sharetype',
-                        'data-sharetype-%s' % utils.transform_dashed_name(
-                            st.name): _("Share Network"),
+                        'data-sharetype-%s' % st.name: _("Share Network"),
                     }))
                 self.fields[sn_field_name] = sn_field
 
@@ -118,9 +112,8 @@ class CreateForm(forms.SelfHandlingForm):
 
         if self.enable_public_shares:
             self.fields['is_public'] = forms.BooleanField(
-                label=_("Make visible for all"), required=False,
-                help_text=(
-                    "If set then all tenants will be able to see this share."))
+                label=_("Make visible to users from all projects"),
+                required=False)
 
         self.fields['share_proto'].choices = [(sp, sp) for sp in
                                               self.enabled_share_protocols]
@@ -181,19 +174,20 @@ class CreateForm(forms.SelfHandlingForm):
         cleaned_data = super(CreateForm, self).clean()
         form_errors = list(self.errors)
 
-        chosen_share_type = cleaned_data.get('share_type')
-        if chosen_share_type:
-            # NOTE(vponomaryov): skip errors for share-network fields that are
-            # not related to chosen share type.
-            for error in form_errors:
-                st_name = error.split(self.sn_field_name_prefix)[-1]
-                if (error.startswith(self.sn_field_name_prefix) and
-                        st_name != chosen_share_type):
-                    cleaned_data[error] = 'Not set'
-                    self.errors.pop(error, None)
+        # NOTE(vponomaryov): skip errors for share-network fields that are not
+        # related to chosen share type.
+        for error in form_errors:
+            st_name = error.split(self.sn_field_name_prefix)[-1]
+            chosen_st = cleaned_data.get('share_type')
+            if (error.startswith(self.sn_field_name_prefix) and
+                    st_name != chosen_st):
+                cleaned_data[error] = 'Not set'
+                self.errors.pop(error, None)
 
+        share_type = cleaned_data.get('share_type')
+        if share_type:
             cleaned_data['share_network'] = cleaned_data.get(
-                self.sn_field_name_prefix + cleaned_data.get('share_type'))
+                self.sn_field_name_prefix + share_type)
 
         return cleaned_data
 
@@ -234,7 +228,7 @@ class CreateForm(forms.SelfHandlingForm):
                 proto=data['share_proto'],
                 share_network=share_network,
                 snapshot_id=snapshot_id,
-                share_type=utils.transform_dashed_name(data['share_type']),
+                share_type=data['share_type'],
                 is_public=is_public,
                 metadata=metadata,
                 availability_zone=data['availability_zone'],
@@ -261,12 +255,9 @@ class UpdateForm(forms.SelfHandlingForm):
     name = forms.CharField(max_length="255", label=_("Share Name"))
     description = forms.CharField(widget=forms.Textarea,
                                   label=_("Description"), required=False)
-    is_public = forms.ChoiceField(
-        choices=((None, 'Do not change share visibility'),
-                 (False, "Make it 'Private'"), (True, "Make it 'Public'")),
-        label=_("Visibility"), required=False,
-        widget=forms.Select(
-            attrs={'class': 'switched', 'data-slug': 'sharetype'}))
+    is_public = forms.BooleanField(
+        label=_("Make visible to users from all projects"),
+        required=False)
 
     def __init__(self, request, *args, **kwargs):
         super(UpdateForm, self).__init__(request, *args, **kwargs)
@@ -356,7 +347,7 @@ class AddRule(forms.SelfHandlingForm):
                 request, _('Unable to add rule.'), redirect=redirect)
 
 
-class ExtendForm(forms.SelfHandlingForm):
+class ResizeForm(forms.SelfHandlingForm):
     name = forms.CharField(
         max_length="255", label=_("Share Name"),
         widget=forms.TextInput(attrs={'readonly': 'readonly'}),
@@ -370,16 +361,21 @@ class ExtendForm(forms.SelfHandlingForm):
     )
 
     new_size = forms.IntegerField(
-        label=_("New Size (GiB)"),
+        label=_("New Size (GiB)")
     )
 
     def clean(self):
-        cleaned_data = super(ExtendForm, self).clean()
+        cleaned_data = super(ResizeForm, self).clean()
         new_size = cleaned_data.get('new_size')
         orig_size = self.initial['orig_size']
 
-        if new_size <= orig_size:
-            message = _("New size must be greater than current size.")
+        if new_size == orig_size:
+            message = _("New size must be different than the existing size")
+            self._errors["new_size"] = self.error_class([message])
+            return cleaned_data
+
+        if new_size <= 0:
+            message = _("New size should not be less than or equal to zero")
             self._errors["new_size"] = self.error_class([message])
             return cleaned_data
 
@@ -396,16 +392,36 @@ class ExtendForm(forms.SelfHandlingForm):
 
     def handle(self, request, data):
         share_id = self.initial['share_id']
+        new_size = data['new_size']
+        orig_size = data['orig_size']
         try:
-            manila.share_extend(request, share_id, data['new_size'])
-            message = _('Extend share "%s"') % data['name']
-            messages.success(request, message)
-            return True
+            manila.share_resize(request, share_id, new_size, orig_size)
+            return self.check_size(request, share_id, new_size)
         except Exception:
             redirect = reverse("horizon:project:shares:index")
-            exceptions.handle(request,
-                              _('Unable to extend share.'),
-                              redirect=redirect)
+            exceptions.handle(request, _(
+                'Unable to resize share.'), redirect=redirect)
+
+    def check_size(self, request, share_id, new_size):
+        share = manila.share_get(request, share_id)
+        timeout = 30
+        interval = 0.35
+        time_elapsed = 0
+        while share.status != 'available':
+            time.sleep(interval)
+            time_elapsed += interval
+            share = manila.share_get(request, share_id)
+            if time_elapsed > timeout:
+                raise exceptions.WorkflowError(_(
+                    "The operation timed out while resizing. "
+                    "Please try again."))
+
+        if share.size == new_size:
+            message = _('Resized share "%s"') % share.name
+            messages.success(request, message)
+            return True
+        raise exceptions.WorkflowError(_(
+            "Unable to resize share. "))
 
 
 class RevertForm(forms.SelfHandlingForm):
