@@ -14,9 +14,9 @@
 
 from django.conf import urls
 
-from manila_ui.api import manila
 from manila_ui.dashboards.project.shares.replicas import views as replica_views
 from manila_ui.dashboards.project.shares import views as shares_views
+from manila_ui import features
 
 
 urlpatterns = [
@@ -49,16 +49,16 @@ urlpatterns = [
         shares_views.UpdateMetadataView.as_view(),
         name='update_metadata'),
     urls.url(
-        r'^(?P<share_id>[^/]+)/extend/$',
-        shares_views.ExtendView.as_view(),
-        name='extend'),
+        r'^(?P<share_id>[^/]+)/resize/$',
+        shares_views.ResizeView.as_view(),
+        name='resize'),
     urls.url(
         r'^(?P<share_id>[^/]+)/revert/$',
         shares_views.RevertView.as_view(),
         name='revert'),
 ]
 
-if manila.is_replication_enabled():
+if features.is_replication_enabled():
     urlpatterns.extend([
         urls.url(
             r'^(?P<share_id>[^/]+)/create_replica/$',
