@@ -92,21 +92,15 @@ class ShareViewTests(test.APITestCase):
         share = test_data.share
         share_net = test_data.active_share_network
         share_nets = [share_net]
-        fake_share_type = mock.Mock()
-        fake_share_type.name = 'fake-type'
-        fake_share_type.id = '5f3f4705-153d-4864-9930-a01c6bbea0bb'
-        fake_share_type.get_keys = mock.Mock(return_value={
-            'driver_handles_share_servers': 'True'})
         formData = {
-            'name': u'new_share',
-            'description': u'This is test share',
-            'method': u'CreateForm',
+            'name': 'new_share',
+            'description': 'This is test share',
+            'method': 'CreateForm',
             'share_network': share_net.id,
             'size': 1,
-            'share_proto': u'NFS',
-            'share_type': utils.transform_dashed_name('fake-type'),
-            'share-network-choices-%s' % utils.transform_dashed_name(
-                'fake-type'): share_net.id,
+            'share_proto': 'NFS',
+            'share_type': 'fake',
+            'share-network-choices-fake': share_net.id,
             'availability_zone': 'fake_az',
         }
 
@@ -120,7 +114,7 @@ class ShareViewTests(test.APITestCase):
             mock.Mock(return_value=share_nets))
         self.mock_object(
             api_manila, "share_type_list",
-            mock.Mock(return_value=[fake_share_type, ]))
+            mock.Mock(return_value=[self.fake_share_type, ]))
 
         res = self.client.post(url, formData)
 
@@ -130,7 +124,7 @@ class ShareViewTests(test.APITestCase):
             description=formData['description'], proto=formData['share_proto'],
             snapshot_id=None, is_public=False,
             share_group_id=None, share_network=share_net.id,
-            metadata={}, share_type='fake-type',
+            metadata={}, share_type=formData['share_type'],
             availability_zone=formData['availability_zone'])
         api_manila.share_snapshot_list.assert_called_once_with(mock.ANY)
         api_manila.share_network_list.assert_called_once_with(mock.ANY)
@@ -144,9 +138,9 @@ class ShareViewTests(test.APITestCase):
         snapshot = test_data.snapshot
         url = reverse('horizon:project:shares:create')
         formData = {
-            'name': u'new_share',
-            'description': u'This is test share from snapshot',
-            'method': u'CreateForm',
+            'name': 'new_share',
+            'description': 'This is test share from snapshot',
+            'method': 'CreateForm',
             'share_network': share_net.id,
             'size': snapshot.size,
             'share_proto': 'NFS',
@@ -295,7 +289,7 @@ class ShareViewTests(test.APITestCase):
         self.assertRedirectsNoFollow(res, INDEX_URL)
         api_manila.share_update.assert_called_once_with(
             mock.ANY, self.share, formData['name'], formData['description'],
-            is_public=str(formData['is_public']))
+            is_public=formData['is_public'])
         api_manila.share_get.assert_has_calls(
             [mock.call(mock.ANY, self.share.id) for i in (1, 2)])
 
@@ -328,7 +322,7 @@ class ShareViewTests(test.APITestCase):
         self.mock_object(api_manila, "share_allow")
         formData = {
             'access_type': 'user',
-            'method': u'CreateForm',
+            'method': 'CreateForm',
             'access_to': 'someuser',
             'access_level': 'rw',
         }
@@ -360,9 +354,9 @@ class ShareViewTests(test.APITestCase):
             mock.ANY, self.share.id, rule.id)
         api_manila.share_rules_list.assert_called_with(mock.ANY, self.share.id)
 
-    def test_extend_share_get(self):
+    def test_resize_share_get(self):
         share = test_data.share
-        url = reverse('horizon:project:shares:extend', args=[share.id])
+        url = reverse('horizon:project:shares:resize', args=[share.id])
         self.mock_object(
             neutron, "is_service_enabled", mock.Mock(return_value=[True]))
 
@@ -370,24 +364,24 @@ class ShareViewTests(test.APITestCase):
 
         api_manila.share_get.assert_called_once_with(mock.ANY, share.id)
         self.assertNoMessages()
-        self.assertTemplateUsed(res, 'project/shares/extend.html')
+        self.assertTemplateUsed(res, 'project/shares/resize.html')
 
-    def test_extend_share_open_form_successfully(self):
+    def test_resize_share_open_form_successfully(self):
         self.share.size = 5
-        url = reverse('horizon:project:shares:extend', args=[self.share.id])
-        self.mock_object(api_manila, "share_extend")
+        url = reverse('horizon:project:shares:resize', args=[self.share.id])
+        self.mock_object(api_manila, "share_resize")
 
         response = self.client.get(url)
 
         self.assertEqual(200, response.status_code)
-        self.assertTemplateUsed(response, 'project/shares/extend.html')
+        self.assertTemplateUsed(response, 'project/shares/resize.html')
         api_manila.share_get.assert_called_once_with(mock.ANY, self.share.id)
-        self.assertFalse(api_manila.share_extend.called)
+        self.assertFalse(api_manila.share_resize.called)
         api_manila.tenant_absolute_limits.assert_called_once_with(mock.ANY)
 
-    def test_extend_share_get_with_api_exception(self):
-        url = reverse('horizon:project:shares:extend', args=[self.share.id])
-        self.mock_object(api_manila, "share_extend")
+    def test_resize_share_get_with_api_exception(self):
+        url = reverse('horizon:project:shares:resize', args=[self.share.id])
+        self.mock_object(api_manila, "share_resize")
         self.mock_object(
             api_manila, "share_get",
             mock.Mock(return_value=Exception('Fake share NotFound exception')))
@@ -396,22 +390,22 @@ class ShareViewTests(test.APITestCase):
 
         self.assertEqual(404, response.status_code)
         self.assertTemplateNotUsed(
-            response, 'project/shares/shares/extend.html')
-        self.assertFalse(api_manila.share_extend.called)
+            response, 'project/shares/shares/resize.html')
+        self.assertFalse(api_manila.share_resize.called)
         api_manila.share_get.assert_called_once_with(mock.ANY, self.share.id)
         self.assertFalse(api_manila.tenant_absolute_limits.called)
 
-    @ddt.data(6, 54, 55)
-    def test_extend_share_post_successfully(self, new_size):
+    @ddt.data(6, 54, 1, 2, 21)
+    def test_resize_share_post_successfully(self, new_size):
         self.share.size = 5
-        form_data = {'new_size': new_size}
+        form_data = {'new_size': new_size, 'orig_size': self.share.size}
         usage_limit = {
             'maxTotalShareGigabytes': self.share.size + 50,
             'totalShareGigabytesUsed': self.share.size,
 
         }
-        url = reverse('horizon:project:shares:extend', args=[self.share.id])
-        self.mock_object(api_manila, "share_extend")
+        url = reverse('horizon:project:shares:resize', args=[self.share.id])
+        self.mock_object(api_manila, "share_resize")
         self.mock_object(
             api_manila, 'tenant_absolute_limits',
             mock.Mock(return_value=usage_limit))
@@ -420,23 +414,28 @@ class ShareViewTests(test.APITestCase):
 
         self.assertEqual(302, response.status_code)
         self.assertTemplateNotUsed(
-            response, 'project/shares/extend.html')
-        api_manila.share_get.assert_called_once_with(mock.ANY, self.share.id)
-        api_manila.share_extend.assert_called_once_with(
-            mock.ANY, self.share.id, form_data['new_size'])
+            response, 'project/shares/resize.html')
+        calls = [
+            mock.call(mock.ANY, self.share.id),
+            mock.call(mock.ANY, self.share.id)]
+        api_manila.share_get.assert_has_calls(calls)
+        api_manila.share_resize.assert_called_once_with(
+            mock.ANY, self.share.id, form_data['new_size'],
+            form_data['orig_size'])
         api_manila.tenant_absolute_limits.assert_called_once_with(mock.ANY)
         self.assertRedirectsNoFollow(response, INDEX_URL)
 
-    @ddt.data(0, 5, 56)
-    def test_extend_share_post_with_invalid_value(self, new_size):
+    @ddt.data(5, 56, 0, -1)
+    def test_resize_share_post_with_invalid_value(self, new_size):
         self.share.size = 5
-        form_data = {'new_size': new_size}
-        url = reverse('horizon:project:shares:extend', args=[self.share.id])
+        form_data = {'new_size': new_size, 'orig_size': self.share.size}
+
+        url = reverse('horizon:project:shares:resize', args=[self.share.id])
         usage_limit = {
             'maxTotalShareGigabytes': self.share.size + 50,
             'totalShareGigabytesUsed': self.share.size,
         }
-        self.mock_object(api_manila, "share_extend")
+        self.mock_object(api_manila, "share_resize")
         self.mock_object(
             api_manila, 'tenant_absolute_limits',
             mock.Mock(return_value=usage_limit))
@@ -444,27 +443,31 @@ class ShareViewTests(test.APITestCase):
         response = self.client.post(url, form_data)
 
         self.assertEqual(200, response.status_code)
-        self.assertTemplateUsed(response, 'project/shares/extend.html')
-        self.assertFalse(api_manila.share_extend.called)
+        self.assertTemplateUsed(response, 'project/shares/resize.html')
+        self.assertFalse(api_manila.share_resize.called)
         api_manila.share_get.assert_called_once_with(mock.ANY, self.share.id)
         api_manila.tenant_absolute_limits.assert_called_with(mock.ANY)
 
-    def test_extend_share_post_with_api_exception(self):
+    def test_resize_share_post_with_api_exception(self):
         self.share.size = 5
-        form_data = {'new_size': 30}
-        url = reverse('horizon:project:shares:extend', args=[self.share.id])
+        form_data = {'new_size': 30, 'orig_size': self.share.size}
+        url = reverse('horizon:project:shares:resize', args=[self.share.id])
         self.mock_object(
-            api_manila, "share_extend",
+            api_manila, "share_resize",
             mock.Mock(return_value=Exception('Fake API exception')))
 
         response = self.client.post(url, form_data)
 
         self.assertEqual(302, response.status_code)
         self.assertTemplateNotUsed(
-            response, 'project/shares/extend.html')
-        api_manila.share_extend.assert_called_once_with(
-            mock.ANY, self.share.id, form_data['new_size'])
-        api_manila.share_get.assert_called_once_with(mock.ANY, self.share.id)
+            response, 'project/shares/resize.html')
+        api_manila.share_resize.assert_called_once_with(
+            mock.ANY, self.share.id, form_data['new_size'],
+            form_data['orig_size'])
+        calls = [
+            mock.call(mock.ANY, self.share.id),
+            mock.call(mock.ANY, self.share.id)]
+        api_manila.share_get.assert_has_calls(calls)
         api_manila.tenant_absolute_limits.assert_called_once_with(mock.ANY)
         self.assertRedirectsNoFollow(response, INDEX_URL)
 
@@ -625,12 +628,12 @@ class ShareViewTests(test.APITestCase):
             mock.Mock(return_value=[self.FakeAZ('fake_az'), ]))
 
         data = {
-            'name': u'new_share',
-            'description': u'This is test share',
-            'method': u'CreateForm',
+            'name': 'new_share',
+            'description': 'This is test share',
+            'method': 'CreateForm',
             'share_network': test_data.active_share_network.id,
             'size': 1,
-            'share_proto': u'NFS',
+            'share_proto': 'NFS',
             'share_type': 'fake',
             'share-network-choices-fake': test_data.active_share_network.id,
             'availability_zone': 'fake_az',
@@ -688,8 +691,8 @@ class ShareViewTests(test.APITestCase):
             api_manila, "share_update", mock.Mock(return_value=self.share))
 
         data = {
-            'name': u'old_share',
-            'description': u'This is test share',
+            'name': 'old_share',
+            'description': 'This is test share',
         }
         if enable_public_shares:
             data.update({'is_public': is_public})
